@@ -1,14 +1,12 @@
 ###############################################################################
 #
-# This file copyright (c) 2001 by Randy J. Ray, all rights reserved
+# This file copyright (c) 2001-2008 Randy J. Ray, all rights reserved
 #
-# Copying and distribution are permitted under the terms of the Artistic
-# License as distributed with Perl versions 5.005 and later. See
-# http://www.opensource.org/licenses/artistic-license.php
+# See "LICENSE" in the documentation for licensing and redistribution terms.
 #
 ###############################################################################
 #
-#   $Id: Status.pm,v 1.5 2004/12/09 08:50:17 rjray Exp $
+#   $Id: Status.pm 343 2008-04-09 09:54:36Z rjray $
 #
 #   Description:    This module is intended to provide a browser-friendly
 #                   status page on the RPC server(s) being managed by the
@@ -17,7 +15,19 @@
 #                   Some parts of this are borrowed from the Apache::Status
 #                   module.
 #
-#   Functions:      handler
+#   Functions:      new
+#                   version
+#                   handler
+#                   init_handler
+#                   apache_status_attach
+#                   header
+#                   footer
+#                   make_url
+#                   main_screen
+#                   server_summary
+#                   server_detail
+#                   method_summary
+#                   method_detail
 #
 #   Libraries:      Apache
 #                   Apache::Constants
@@ -34,8 +44,8 @@ use 5.005;
 use strict;
 use vars qw(%IS_INSTALLED $SERVER_VER $STARTED $PERL_VER $DEFAULT $SERVER_CLASS
             %proto $newQ);
-use subs qw(header footer main_screen srv_summary server_detail meth_summary
-            method_detail);
+use subs qw(header footer main_screen server_summary server_detail
+            method_summary method_detail);
 
 use Apache;
 use Apache::Constants qw(DECLINED OK SERVER_VERSION);
@@ -50,7 +60,7 @@ $SERVER_CLASS = 'Apache::RPC::Server';
 $STARTED    = scalar localtime $^T;
 $PERL_VER   = $^V ? sprintf "v%vd", $^V : $];
 
-$Apache::RPC::Status::VERSION = do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
+$Apache::RPC::Status::VERSION = '1.07';
 
 #
 # %proto is the prototype set of screens/handlers that this class knows about.
@@ -91,11 +101,9 @@ sub new
     bless \%self, $class;
 }
 
-#
 # This retrieves the default object for use within handler() below. Basically,
 # handler() needs a blessed reference to operate on so that it can call the
 # header() and footer() routines as methods to allow for subclassing.
-#
 sub default_object
 {
     return $DEFAULT if (ref $DEFAULT);
@@ -356,9 +364,9 @@ sub main_screen
                                      # calls to make_url()
                                      $Q->a({ -href => "$uri&server=$_" },
                                            $server)),
-                              $Q->td(srv_summary($Q,
-                                                 $SERVER_CLASS->
-                                                 get_server($_))));
+                              $Q->td(server_summary($Q,
+                                                    $SERVER_CLASS->
+                                                    get_server($_))));
                    } (@servers))));
 
     \@lines;
@@ -366,7 +374,7 @@ sub main_screen
 
 ###############################################################################
 #
-#   Sub Name:       srv_summary
+#   Sub Name:       server_summary
 #
 #   Description:    Produce the summary table of server info for the main
 #                   status page.
@@ -378,7 +386,7 @@ sub main_screen
 #   Returns:        text chunk
 #
 ###############################################################################
-sub srv_summary
+sub server_summary
 {
     my ($Q, $srv) = @_;
 
@@ -423,7 +431,7 @@ sub server_detail
     $server = $Q->param('server');
     # Override this before calling make_url:
     $Q->param(-name => 'screen', -value => 'method');
-    # Now create the base URL string for meth_summary to use
+    # Now create the base URL string for method_summary to use
     $base_url = $self->make_url($Q, $flag);
     if (! $server)
     {
@@ -467,14 +475,14 @@ sub server_detail
         {
             ($meth1, $meth2) = splice(@methods, 0, 2);
             push(@lines, '<tr valign="top"><td width="50%">');
-            push(@lines, meth_summary($Q, $server, $srv->get_method($meth1),
-                                      $base_url));
+            push(@lines, method_summary($Q, $server, $srv->get_method($meth1),
+                                        $base_url));
             push(@lines, '</td><td width="50%">');
             if ($meth2)
             {
-                push(@lines, meth_summary($Q, $server,
-                                          $srv->get_method($meth2),
-                                          $base_url));
+                push(@lines, method_summary($Q, $server,
+                                            $srv->get_method($meth2),
+                                            $base_url));
             }
             else
             {
@@ -491,7 +499,7 @@ sub server_detail
 
 ###############################################################################
 #
-#   Sub Name:       meth_summary
+#   Sub Name:       method_summary
 #
 #   Description:    Create the HTML table for a method-object summary
 #
@@ -507,7 +515,7 @@ sub server_detail
 #   Returns:        text
 #
 ###############################################################################
-sub meth_summary
+sub method_summary
 {
     my ($Q, $server, $meth, $base_url) = @_;
 
@@ -800,6 +808,32 @@ issues:
 
 =over 4
 
+=item version
+
+(May be called as a static method.) Returns the current version of this
+module.
+
+=item apache_status_attach
+
+Attach the B<Apache::RPC::Status> module to the main screen of the
+B<Apache::Status> display.
+
+=item default_object
+
+(May be called as a static method.) Returns a default B<Apache::RPC::Status>
+instance when called as a static method. Returns the calling reference itself,
+otherwise.
+
+=item header(REQUEST, TITLE)
+
+Produces the HTML header for a page. Uses the passed-in title parameter to
+give the page a title, and extracts any request-specific information from the
+B<Apache> request object passed as the first parameter.
+
+=item footer(REQUEST)
+
+Produces the HTML footer.
+
 =item make_url(QUERY|REQUEST, FLAG)
 
 (May be called as a static method.) This creates a URL string for use as a
@@ -811,6 +845,38 @@ tailored for use with B<Apache::Status>. The first argument must be either the
 original request object as passed by mod_perl, or a reference to a CGI object
 created from the request (see L<CGI> for more on the CGI class).
 
+=item main_screen(REQUEST, QUERY, INTERNAL)
+
+Renders the HTML (minus the header and footer) for the main screen. The
+arguments are the B<Apache> request object, a B<CGI> query object created
+from the request, and a boolean flag indicating whether the call into this
+method was made from within this module or made from the B<Apache::Status>
+page.
+
+=item server_summary(SERVER)
+
+Creates an HTML snippet to provide a summary for the server passed in as an
+argument. The passed-in value should be the server object, not the name.
+
+=item server_detail(REQUEST, QUERY, INTERNAL)
+
+Renders the HTML (minus header and footer) for a screen describing a server
+instance in detail. The server is specified by name in the query parameters.
+The arguments are the same as for C<main_screen>.
+
+=item method_summary(SERVER, METHOD, BASEURL)
+
+Creates and HTML snippet to provide a summary for the specified method of the
+specified server. The third argument is a base-URL to use for making links to
+the detailed method page.
+
+=item method_detail(REQUEST, QUERY, INTERNAL)
+
+Renders the HTML (minus header and footer) for a screen describing a method on
+a specific server instance, in detail. The method and server are specified by
+name in the query parameters. The arguments are the same as for
+C<main_screen>.
+
 =back
 
 =head2 Use and Extension Within Perl Sections
@@ -895,9 +961,12 @@ this were carefully considered, so any such changes should be minimal.
 
 =head1 LICENSE
 
-This module is licensed under the terms of the Artistic License that covers
-Perl. See <http://www.opensource.org/licenses/artistic-license.php> for the
-license itself.
+This module and the code within are released under the terms of the Artistic
+License 2.0
+(http://www.opensource.org/licenses/artistic-license-2.0.php). This code may
+be redistributed under either the Artistic License or the GNU Lesser General
+Public License (LGPL) version 2.1
+(http://www.opensource.org/licenses/lgpl-license.php).
 
 =head1 SEE ALSO
 
