@@ -1,15 +1,12 @@
 ###############################################################################
 #
-# This file copyright (c) 2001 by Randy J. Ray <rjray@blackperl.com>,
-# all rights reserved
+# This file copyright (c) 2001-2008 Randy J. Ray, all rights reserved
 #
-# Copying and distribution are permitted under the terms of the Artistic
-# License as distributed with Perl versions 5.002 and later. See
-# http://language.perl.com/misc/Artistic.html
+# See "LICENSE" in the documentation for licensing and redistribution terms.
 #
 ###############################################################################
 #
-#   $Id: Client.pm,v 1.20 2020/05/14 09:22:07 rjray Exp $
+#   $Id: Client.pm 343 2008-04-09 09:54:36Z rjray $
 #
 #   Description:    This class implements an RPC::XML client, using LWP to
 #                   manage the underlying communication protocols. It relies
@@ -46,7 +43,7 @@ require URI;
 use RPC::XML 'bytelength';
 require RPC::XML::Parser;
 
-$VERSION = do { my @r=(q$Revision: 1.20 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
+$VERSION = '1.24';
 
 ###############################################################################
 #
@@ -203,7 +200,7 @@ sub send_request
     my ($me, $message, $response, $reqclone, $content, $can_compress, $value,
         $do_compress, $req_fh, $tmpfile, $com_engine);
 
-    $me = ref($self) . ':send_request';
+    $me = ref($self) . '::send_request';
 
     if (! UNIVERSAL::isa($req, 'RPC::XML::request'))
     {
@@ -218,7 +215,7 @@ sub send_request
     $reqclone->header(Host => URI->new($reqclone->uri)->host);
     $can_compress = $self->compress; # Avoid making 4+ calls to the method
     if ($self->compress_requests and $can_compress and
-        $req->length > $self->compress_thresh)
+        $req->length >= $self->compress_thresh)
     {
         # If this is a candidate for compression, set a flag and note it
         # in the Content-encoding header.
@@ -230,13 +227,14 @@ sub send_request
     # threshhold for a requested file cut-off, send it to a temp file and use
     # a closure on the request object to manage content.
     if ($self->message_file_thresh and
-        $self->message_file_thresh < $req->length)
+        $self->message_file_thresh <= $req->length)
     {
         require File::Spec;
         require Symbol;
         # Start by creating a temp-file
         $tmpfile = $self->message_temp_dir || File::Spec->tmpdir;
-        $tmpfile = File::Spec->catfile($tmpfile, __PACKAGE__ . $$ . time);
+        ($tmpfile = File::Spec->catfile($tmpfile, __PACKAGE__ . $$ . time)) =~
+            s/::/-/g; # Colons in filenames bad on some systems!
         $req_fh = Symbol::gensym();
         return "$me: Error opening $tmpfile: $!"
             unless (open($req_fh, "+> $tmpfile"));
@@ -249,7 +247,7 @@ sub send_request
         # request could theoretically be HUGE, in order to compress we have to
         # write it to a second temp-file first, so that we can compress it
         # into the primary handle.
-        if ($do_compress)
+        if ($do_compress && ($req->length >= $self->compress_thresh))
         {
             my $fh2 = Symbol::gensym();
             $tmpfile .= '-2';
@@ -726,7 +724,7 @@ outgoing messages that are longer than the threshhold setting in bytes.
 With no arguments, returns the current compression threshhold; messages
 smaller than this number of bytes will not be compressed, regardless of the
 above method setting. If a number is passed, this is set to the new
-lower-limit. The default value is 4096.
+lower-limit. The default value is 4096 (4k).
 
 =back
 
@@ -763,9 +761,12 @@ specification.
 
 =head1 LICENSE
 
-This module is licensed under the terms of the Artistic License that covers
-Perl. See <http://language.perl.com/misc/Artistic.html> for the license
-itself.
+This module and the code within are released under the terms of the Artistic
+License 2.0
+(http://www.opensource.org/licenses/artistic-license-2.0.php). This code may
+be redistributed under either the Artistic License or the GNU Lesser General
+Public License (LGPL) version 2.1
+(http://www.opensource.org/licenses/lgpl-license.php).
 
 =head1 SEE ALSO
 
